@@ -183,7 +183,7 @@ namespace {
      * @cvalue PQERRORS_VERBOSE
      */
     const PGSQL_ERRORS_VERBOSE = UNKNOWN;
-    #if PGVERSION_NUM > 110000
+    #ifdef HAVE_PQERRORS_SQLSTATE
     /**
      * @var int
      * @cvalue PQERRORS_SQLSTATE
@@ -245,6 +245,13 @@ namespace {
      * @cvalue PGRES_TUPLES_OK
      */
     const PGSQL_TUPLES_OK = UNKNOWN;
+#ifdef HAVE_PG_SET_CHUNKED_ROWS_SIZE
+    /**
+     * @var int
+     * @cvalue PGRES_TUPLES_CHUNK
+     */
+    const PGSQL_TUPLES_CHUNK = UNKNOWN;
+#endif
     /**
      * @var int
      * @cvalue PGRES_COPY_OUT
@@ -440,7 +447,6 @@ namespace {
     const PGSQL_TRACE_REGRESS_MODE = UNKNOWN;
 #endif
 
-#ifdef HAVE_PG_CONTEXT_VISIBILITY
     /* For pg_set_error_context_visibility() */
 
     /**
@@ -458,7 +464,6 @@ namespace {
      * @cvalue PQSHOW_CONTEXT_ALWAYS
      */
     const PGSQL_SHOW_CONTEXT_ALWAYS = UNKNOWN;
-#endif
 
     function pg_connect(string $connection_string, int $flags = 0): PgSql\Connection|false {}
 
@@ -475,8 +480,8 @@ namespace {
 
     /**
      * @alias pg_last_error
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_last_error() instead')]
     function pg_errormessage(?PgSql\Connection $connection = null): string {}
 
     /** @refcount 1 */
@@ -497,6 +502,12 @@ namespace {
      */
     function pg_version(?PgSql\Connection $connection = null): array {}
 
+    /**
+     * @return array<string, string|null>
+     * @refcount 1
+     */
+    function pg_jit(?PgSql\Connection $connection = null): array {}
+
     /**
      * @param PgSql\Connection|string $connection
      * @refcount 1
@@ -541,24 +552,24 @@ namespace {
 
     /**
      * @alias pg_num_rows
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_num_rows() instead')]
     function pg_numrows(PgSql\Result $result): int {}
 
     function pg_num_fields(PgSql\Result $result): int {}
 
     /**
      * @alias pg_num_fields
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_num_fields() instead')]
     function pg_numfields(PgSql\Result $result): int {}
 
     function pg_affected_rows(PgSql\Result $result): int {}
 
     /**
      * @alias pg_affected_rows
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_affected_rows() instead')]
     function pg_cmdtuples(PgSql\Result $result): int {}
 
     function pg_last_notice(PgSql\Connection $connection, int $mode = PGSQL_NOTICE_LAST): array|string|bool {}
@@ -570,24 +581,24 @@ namespace {
 
     /**
      * @alias pg_field_name
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_field_name() instead')]
     function pg_fieldname(PgSql\Result $result, int $field): string {}
 
     function pg_field_size(PgSql\Result $result, int $field): int {}
 
     /**
      * @alias pg_field_size
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_field_size() instead')]
     function pg_fieldsize(PgSql\Result $result, int $field): int {}
 
     function pg_field_type(PgSql\Result $result, int $field): string {}
 
     /**
      * @alias pg_field_type
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_field_type() instead')]
     function pg_fieldtype(PgSql\Result $result, int $field): string {}
 
     /** @refcount 1 */
@@ -597,8 +608,8 @@ namespace {
 
     /**
      * @alias pg_field_num
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_field_num() instead')]
     function pg_fieldnum(PgSql\Result $result, string $field): int {}
 
     /**
@@ -610,8 +621,8 @@ namespace {
     /**
      * @param string|int $row
      * @alias pg_fetch_result
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_fetch_result() instead')]
     function pg_result(PgSql\Result $result, $row, string|int $field = UNKNOWN): string|false|null {}
 
     /**
@@ -654,8 +665,8 @@ namespace {
 
     /**
      * @param string|int $row
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_field_prtlen() instead')]
     function pg_fieldprtlen(PgSql\Result $result, $row, string|int $field = UNKNOWN): int|false {}
 
     /** @param string|int|null $row */
@@ -663,16 +674,16 @@ namespace {
 
     /**
      * @param string|int $row
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_field_is_null() instead')]
     function pg_fieldisnull(PgSql\Result $result, $row, string|int $field = UNKNOWN): int|false {}
 
     function pg_free_result(PgSql\Result $result): bool {}
 
     /**
      * @alias pg_free_result
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_free_result() instead')]
     function pg_freeresult(PgSql\Result $result): bool {}
 
     /** @refcount 1 */
@@ -680,8 +691,8 @@ namespace {
 
     /**
      * @alias pg_last_oid
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_last_oid() instead')]
     function pg_getlastoid(PgSql\Result $result): string|int|false {}
 
     function pg_trace(string $filename, string $mode = "w", ?PgSql\Connection $connection = null, int $trace_mode = 0): bool {}
@@ -699,8 +710,8 @@ namespace {
      * @param PgSql\Connection $connection
      * @param string|int $oid
      * @alias pg_lo_create
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_create() instead')]
     function pg_locreate($connection = UNKNOWN, $oid = UNKNOWN): string|int|false {}
 
     /**
@@ -713,8 +724,8 @@ namespace {
      * @param PgSql\Connection $connection
      * @param string|int $oid
      * @alias pg_lo_unlink
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_unlink() instead')]
     function pg_lounlink($connection, $oid = UNKNOWN): bool {}
 
     /**
@@ -728,16 +739,16 @@ namespace {
      * @param PgSql\Connection $connection
      * @param string|int $oid
      * @alias pg_lo_open
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_open() instead')]
     function pg_loopen($connection, $oid = UNKNOWN, string $mode = UNKNOWN): PgSql\Lob|false {}
 
     function pg_lo_close(PgSql\Lob $lob): bool {}
 
     /**
      * @alias pg_lo_close
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_close() instead')]
     function pg_loclose(PgSql\Lob $lob): bool {}
 
     /** @refcount 1 */
@@ -745,24 +756,24 @@ namespace {
 
     /**
      * @alias pg_lo_read
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_read() instead')]
     function pg_loread(PgSql\Lob $lob, int $length = 8192): string|false {}
 
     function pg_lo_write(PgSql\Lob $lob, string $data, ?int $length = null): int|false {}
 
     /**
      * @alias pg_lo_write
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_write() instead')]
     function pg_lowrite(PgSql\Lob $lob, string $data, ?int $length = null): int|false {}
 
     function pg_lo_read_all(PgSql\Lob $lob): int {}
 
     /**
      * @alias pg_lo_read_all
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_read_all() instead')]
     function pg_loreadall(PgSql\Lob $lob): int {}
 
     /**
@@ -778,8 +789,8 @@ namespace {
      * @param string|int $filename
      * @param string|int $oid
      * @alias pg_lo_import
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_import() instead')]
     function pg_loimport($connection, $filename = UNKNOWN, $oid = UNKNOWN): string|int|false {}
 
     /**
@@ -794,8 +805,8 @@ namespace {
      * @param string|int $oid
      * @param string|int $filename
      * @alias pg_lo_export
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_lo_export() instead')]
     function pg_loexport($connection, $oid = UNKNOWN, $filename = UNKNOWN): bool {}
 
     function pg_lo_seek(PgSql\Lob $lob, int $offset, int $whence = SEEK_CUR): bool {}
@@ -813,16 +824,16 @@ namespace {
     /**
      * @param PgSql\Connection|string $connection
      * @alias pg_set_client_encoding
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_set_client_encoding() instead')]
     function pg_setclientencoding($connection, string $encoding = UNKNOWN): int {}
 
     function pg_client_encoding(?PgSql\Connection $connection = null): string {}
 
     /**
      * @alias pg_client_encoding
-     * @deprecated
      */
+    #[\Deprecated(since: '8.0', message: 'use pg_client_encoding() instead')]
     function pg_clientencoding(?PgSql\Connection $connection = null): string {}
 
     function pg_end_copy(?PgSql\Connection $connection = null): bool {}
@@ -938,10 +949,26 @@ namespace {
      * @return array<int, array>|string|false
      * @refcount 1
      */
-    function pg_select(PgSql\Connection $connection, string $table_name, array $conditions, int $flags = PGSQL_DML_EXEC, int $mode = PGSQL_ASSOC): array|string|false {}
+    function pg_select(PgSql\Connection $connection, string $table_name, array $conditions = [], int $flags = PGSQL_DML_EXEC, int $mode = PGSQL_ASSOC): array|string|false {}
 
-#ifdef HAVE_PG_CONTEXT_VISIBILITY
     function pg_set_error_context_visibility(PgSql\Connection $connection, int $visibility): int {}
+
+#ifdef HAVE_PG_RESULT_MEMORY_SIZE
+    function pg_result_memory_size(PgSql\Result $result): int {}
+#endif
+
+    function pg_change_password(PgSql\Connection $connection, string $user, #[\SensitiveParameter] string $password): bool {}
+
+    function pg_put_copy_data(PgSql\Connection $connection, string $cmd): int {}
+    function pg_put_copy_end(PgSql\Connection $connection, ?string $error = null): int {}
+
+    /**
+     * @param resource $socket
+     */
+    function pg_socket_poll($socket, int $read, int $write, int $timeout = -1): int {}
+
+#ifdef HAVE_PG_SET_CHUNKED_ROWS_SIZE
+    function pg_set_chunked_rows_size(PgSql\Connection $connection, int $size): bool {}
 #endif
 }
 
